package cn.iocoder.yudao.module.infra.config;

import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

/**
 * MinIO 配置属性类
 *
 * @author AI Assistant
 */
@Data
@Configuration
@ConfigurationProperties(prefix = "minio")
public class MinioConfigProperties {

    /**
     * MinIO 服务地址
     */
    private String endpoint;

    /**
     * 访问密钥
     */
    private String accessKey;

    /**
     * 密钥
     */
    private String secretKey;

    /**
     * 默认存储桶名称
     */
    private String bucketName;

    /**
     * 分片上传性能配置
     */
    private MultipartConfig multipart = new MultipartConfig();

    @Data
    public static class MultipartConfig {
        /**
         * 使用立即响应模式的分片数阈值（默认100）
         */
        private int instantModeThreshold = 100;

        /**
         * 使用极速模式的分片数阈值（默认50）
         */
        private int turboModeThreshold = 50;

        /**
         * 线程池核心线程数（默认：CPU核心数*2，最小8）
         */
        private int corePoolSize = Math.max(8, Runtime.getRuntime().availableProcessors() * 2);

        /**
         * 线程池最大线程数（默认：核心线程数*4，最大32）
         */
        private int maxPoolSize = Math.min(32, corePoolSize * 4);

        /**
         * 预生成URL的超时时间（秒，默认3秒）
         */
        private int urlGenerateTimeout = 3;

        /**
         * 分批合并的批次大小（默认50）
         * 当分片数量超过此值时，将采用分批并行合并策略
         */
        private int batchSize = 50;
    }

} 